#******************************************************************************
#
# Project ICI-Covid
#
# Obj: Descriptive statistics
#         (1) General DS
#         (2) Share of individuals helped with a task 
#         (3) Share of individuals helped with a task by gender [WIP]
#         (4) Share of individuals with ADL or IADL [WIP]
#
# Authors: Lucas Jeanneau - Quitterie Roquebert - Marianne Tenand
#
# Last modified: 26/02/2020
#
#******************************************************************************

  #Should be run after 1.Variables.R

#### Packages for the program ####

# NB : for first run, need to do "install.packages(NAMEOFTHEPACKAGE)" first
# Then, run library(PACKAGE) at each opening of R

  #install.packages('dplyr')
library(dplyr)
library(tidyr)
library(readxl)
library(writexl)
library(Hmisc)

detach(data_clean)
attach(data_clean) 

### Dataset with variables used for the descriptive statistics ####

data_SD <- as.data.frame(
  cbind(femme,moinsde76,de76a85,de86a90,de91a95,plusde96,aucundiplome,certificatbepcap,
        bacouplus,conjoint_1,conjoint_2,conjoint_3,nbenfant,pasdenfant,enfantdanslaville,enfantpasdanslaville,freresoeur,
        nbiadl_any,nbiadl,nbadl_any,nbadl,group_1,group_2,group_3,alzheimer,santesubj,
        etab_1,etab_2,etab_3,lucratif,lucratif_no,public_hosp,public_hosp_no,
        taille_1,taille_2,taille_3,taille_4, poidsen)
)
#

sumstat <- data_SD %>%
  select(
    'Women' = femme,
    'Age: [60;75]'=moinsde76,
    'Age: ]75;85]'=de76a85,
    'Age: ]85;90]'=de86a90,
    'Age: ]90;95]'=de91a95,
    'Age: >96'=plusde96,
    'No diploma'=aucundiplome,
    'Primary school or lower secondary school diploma'=certificatbepcap,
    'Baccalaurat or higher diploma'=bacouplus,
    'No partner'=conjoint_1,
    'Partner at home'=conjoint_2,
    'Partner in institution'=conjoint_3,
    'Number of children'=nbenfant,
    'Has no child'=pasdenfant,
    'Closest child in same city'=enfantdanslaville,
    'Closest child not in same city'=enfantpasdanslaville,
    'Has siblings'=freresoeur,
    'Any IADL restriction'=nbiadl_any,
    'Number of IADL restrictions'=nbiadl,
    'Any ADL restriction'=nbadl_any,
    'Number of ADL restrictions'=nbadl,
    'Both ADL and IADL restrictions'=group_2,
    'Severely disabled'=group_3,
    'Alzheimer`s disease'=alzheimer,
    'Positive subjective health'=santesubj,
    'Institution type: EHPAD'=etab_1,
    'Institution type: USLD'=etab_2,
    'Institution type: EHPA'=etab_3,
    'For-profit institution'=lucratif,
    'Not-for-profit institution'=lucratif_no,
    'Public hospital institution'=public_hosp,
    'Public non-hospital institution'=public_hosp_no,
    'Institution size: <60 residents'=taille_1,
    'Institution size: [60;99] residents'=taille_2,
    'Institution size: >100 residents'=taille_3,
    'Institution size: unknown'=taille_4, 
    'poidsen' = poidsen
  ) 

  # Compute mean and sd (weighted)
  sumstat <- sumstat  %>%
  summarise_each(funs(wtd.mean(.,poidsen),wtd.var(.,poidsen)),-poidsen) 
  
  sumstat <- sumstat  %>%
  gather(key, value, everything()) %>% 
  separate(key, into = c("variable", "stat"), sep = "_") %>% 
  group_by(stat) %>% mutate(nrow = row_number()) %>% ungroup() %>% 
  spread(stat, value) %>%
  arrange(nrow)  

  # Set order of summary statistics 
  sumstat <- sumstat  %>%
  mutate(mean = wtd.mean, sd = sqrt(wtd.var))  %>%
  select(variable, mean, sd)
    
  # Round all numeric variables to one decimal point
  sumstat <- sumstat  %>%
  mutate_each(funs(round(., 5)), -variable)

sumstat

# Export excel
write_xlsx(sumstat, path = paste0(dropbox, out_DS, "ICI-Covid_Table1.xls"))


#### Weighted proportions of individuals who can't perform ADL ####
###################################################################

  ## TO DO ## 

detach(data_clean)
attach(data_clean) 

#Create a dataset with the variables that will be used for the descriptive statistics table
data_spider <- as.data.frame(
  cbind(toilette,habillage,nourriture,manger,besoins,
        mobilite,menage,administratif,courses,prepnourriture,medicaments,
        telephone,sedeplacer,sortirseul,transportcommun,trouverchemin,poidsen)
)

#### ADLs ####

## Output the weighted proportions for the full population ##

sumstat <- data_spider %>%
  select(
    'ADL: dress'=habillage,
    'ADL: groom'=toilette,
    'ADL: cut food'=nourriture,
    'ADL: eat'=manger,
    'ADL: use toilets'=besoins,
    'ADL: transfer'=mobilite,
    'poidsen' = poidsen
  ) 

sumstat <- sumstat %>%
  summarise_each(funs(wtd.mean(.,poidsen),wtd.var(.,poidsen)),-poidsen) 

sumstat <- sumstat %>%
  gather(key, value, everything()) %>% 
  separate(key, into = c("variable", "stat"), sep = "_") %>% 
  group_by(stat) %>% mutate(nrow = row_number()) %>% ungroup() %>% 
  spread(stat, value) %>%
  arrange(nrow) 

# Set order of summary statistics 
mutate(mean = wtd.mean, sd = sqrt(wtd.var))
select(variable, mean, sd) %>%
  
  # Round all numeric variables to one decimal point
  mutate_each(funs(round(., 5)), -variable)

sumstat

# Export to xlsx file > Imported again in 3.Spider_charts.R to create a radar chart
write_xlsx(sumstat, path = paste0(dropbox, out_DS, "ICI-Covid_Figure1_Restrictions_ADL.xlsx"))


#### IADLs ####

## Output the weighted proportions for the full population ##

sumstat <- data_spider %>%
  select(
    'IADL: move around'=sedeplacer,
    'IADL: administrative tasks'=administratif,
    'IADL: go out'=sortirseul,
    'IADL: manage transportation'=transportcommun,
    'IADL: find way outside'=trouverchemin,
    'IADL: use phone'=telephone,
    'poidsen' = poidsen
  ) 

sumstat <- sumstat %>%
  summarise_each(funs(wtd.mean(.,poidsen),wtd.var(.,poidsen)),-poidsen) 

sumstat <- sumstat %>%
  gather(key, value, everything()) %>% 
  separate(key, into = c("variable", "stat"), sep = "_") %>% 
  group_by(stat) %>% mutate(nrow = row_number()) %>% ungroup() %>% 
  spread(stat, value) %>%
  arrange(nrow) 

# Set order of summary statistics 
mutate(mean = wtd.mean, sd = sqrt(wtd.var))
select(variable, mean, sd) %>%
  
  # Round all numeric variables to one decimal point
  mutate_each(funs(round(., 5)), -variable)

sumstat

# Export to xlsx file > Imported again in 3.Spider_charts.R to create a radar chart
write_xlsx(sumstat, path = paste0(dropbox, out_DS, "ICI-Covid_Figure2_Restrictions_IADL.xlsx"))





#### Weighted proportions of individuals who are helped with ADL or IADL ####
#############################################################################

detach(data_clean)
attach(data_clean) 

#Create a dataset with the variables that will be used for the descriptive statistics table
data_spider <- as.data.frame(
  cbind(femme,raaident_r1,raaident_r2,raaident_r3,raaident_r4,raaident_r5,
        raaident_r6,raaident_r7,raaident_r8,raaident_r9,raaident_r10,raaident_r11,
        raaident_r12,raaident_r13,poidsen)
)

## Output the weighted proportions for the full population ##

sumstat <- data_spider %>%
  select(
    'ADL: groom or dress'=raaident_r1,
    'ADL: cut food and eat'=raaident_r2,
    'ADL: use toilets'=raaident_r10,
    'IADL/ADL: transfer and move around'=raaident_r8,
    'IADL: domestic chores'=raaident_r3,
    'IADL: prepare meals'=raaident_r4,
    'IADL: administrative tasks'=raaident_r5,
    'IADL: do the grocery'=raaident_r6,
    'IADL: take medication'=raaident_r7,
    'IADL: go out'=raaident_r9,
    'IADL: manage transportation'=raaident_r11,
    'IADL: find way outside'=raaident_r12,
    'IADL: use phone'=raaident_r13,
    'poidsen' = poidsen
  ) 

sumstat <- sumstat %>%
  summarise_each(funs(wtd.mean(.,poidsen),wtd.var(.,poidsen)),-poidsen) 

sumstat <- sumstat %>%
  gather(key, value, everything()) %>% 
  separate(key, into = c("variable", "stat"), sep = "_") %>% 
  group_by(stat) %>% mutate(nrow = row_number()) %>% ungroup() %>% 
  spread(stat, value) %>%
  arrange(nrow) 

# Set order of summary statistics 
mutate(mean = wtd.mean, sd = sqrt(wtd.var))
select(variable, mean, sd) %>%
  
  # Round all numeric variables to one decimal point
  mutate_each(funs(round(., 5)), -variable)

sumstat

# Export to xlsx file > Imported again in 3.Spider_charts.R to create a radar chart
write_xlsx(sumstat, path = paste0(dropbox, out_DS, "ICI-Covid_Figure4_Tasks_All.xlsx"))



## Output the weighted proportions for women only ##

data_spider_woman <- subset(data_spider, femme == "1")
data_spider_woman <- as.data.frame(data_spider_woman)

sumstat <- data_spider_woman %>%
  select(
    'ADL: groom or dress'=raaident_r1,
    'ADL: cut food and eat'=raaident_r2,
    'ADL: use toilets'=raaident_r10,
    'IADL/ADL: transfer and move around'=raaident_r8,
    'IADL: domestic chores'=raaident_r3,
    'IADL: prepare meals'=raaident_r4,
    'IADL: administrative tasks'=raaident_r5,
    'IADL: do the grocery'=raaident_r6,
    'IADL: take medication'=raaident_r7,
    'IADL: go out'=raaident_r9,
    'IADL: manage transportation'=raaident_r11,
    'IADL: find way outside'=raaident_r12,
    'IADL: use phone'=raaident_r13,
    'poidsen' = poidsen
  ) 

sumstat <- sumstat %>%
  summarise_each(funs(wtd.mean(.,poidsen),wtd.var(.,poidsen)),-poidsen) 

sumstat <- sumstat %>%
  gather(key, value, everything()) %>% 
  separate(key, into = c("variable", "stat"), sep = "_") %>% 
  group_by(stat) %>% mutate(nrow = row_number()) %>% ungroup() %>% 
  spread(stat, value) %>%
  arrange(nrow) 

# Set order of summary statistics 
mutate(mean = wtd.mean, sd = sqrt(wtd.var))
select(variable, mean, sd) %>%
  
  # Round all numeric variables to one decimal point
  mutate_each(funs(round(., 5)), -variable)

sumstat

# Export to xlsx file > Imported again in 3.Spider_charts.R to create a radar chart
write_xlsx(sumstat, path = paste0(dropbox, out_DS, "ICI-Covid_Figure4_Tasks_a.Women.xlsx"))



## Output the weighted proportions for women only ##

data_spider_man <- subset(data_spider, femme == "0")
data_spider_man <- as.data.frame(data_spider_man)

sumstat <- data_spider_man %>%
  select(
    'ADL: groom or dress'=raaident_r1,
    'ADL: cut food and eat'=raaident_r2,
    'ADL: use toilets'=raaident_r10,
    'IADL/ADL: transfer and move around'=raaident_r8,
    'IADL: domestic chores'=raaident_r3,
    'IADL: prepare meals'=raaident_r4,
    'IADL: administrative tasks'=raaident_r5,
    'IADL: do the grocery'=raaident_r6,
    'IADL: take medication'=raaident_r7,
    'IADL: go out'=raaident_r9,
    'IADL: manage transportation'=raaident_r11,
    'IADL: find way outside'=raaident_r12,
    'IADL: use phone'=raaident_r13,
    'poidsen' = poidsen
  ) 

sumstat <- sumstat %>%
  summarise_each(funs(wtd.mean(.,poidsen),wtd.var(.,poidsen)),-poidsen) 

sumstat <- sumstat %>%
  gather(key, value, everything()) %>% 
  separate(key, into = c("variable", "stat"), sep = "_") %>% 
  group_by(stat) %>% mutate(nrow = row_number()) %>% ungroup() %>% 
  spread(stat, value) %>%
  arrange(nrow) 

# Set order of summary statistics 
mutate(mean = wtd.mean, sd = sqrt(wtd.var))
select(variable, mean, sd) %>%
  
  # Round all numeric variables to one decimal point
  mutate_each(funs(round(., 5)), -variable)

sumstat

# Export to xlsx file > Imported again in 3.Spider_charts.R to create a radar chart
write_xlsx(sumstat, path = paste0(dropbox, out_DS, "ICI-Covid_Figure4_Tasks_b.Men.xlsx"))

